@@ -6,11 +6,12 @@
 
   xysegint     compute intersections between line segments
 
-  $Revision: 1.1 $     $Date: 2006/05/22 06:42:07 $
+  $Revision: 1.5 $     $Date: 2007/03/16 12:49:51 $
 
  */
 
 #include <math.h>
+#include <stdio.h>
 
 #define NIETS -1.0
 
@@ -90,6 +91,44 @@ void xysegint(na, x0a, y0a, dxa, dya,
     }
 }
 	 
+void xysi(na, x0a, y0a, dxa, dya, 
+              nb, x0b, y0b, dxb, dyb, 
+	      eps,
+              ok)
+     /* inputs (vectors of coordinates) */
+     int *na, *nb;
+     double *x0a, *y0a, *dxa, *dya, *x0b, *y0b, *dxb, *dyb;
+     /* input (tolerance for determinant) */
+     double *eps;  
+     /* output (logical) */
+     int *ok;
+{ 
+  int i, j, ma, mb;
+  double determinant, absdet, diffx, diffy, tta, ttb;
+
+  *ok = 0;
+  ma = *na;
+  mb = *nb;
+  for (j=0; j < mb; j++) 
+    {
+      for(i = 0; i < ma; i++) {
+	determinant = dxb[j] * dya[i] - dyb[j] * dxa[i];
+	absdet = (determinant > 0) ? determinant : -determinant;
+	if(absdet > *eps) {
+	  diffx = (x0b[j] - x0a[i])/determinant;
+	  diffy = (y0b[j] - y0a[i])/determinant;
+	  tta = - dyb[j] * diffx + dxb[j] * diffy;
+	  ttb = - dya[i] * diffx + dxa[i] * diffy;
+	  if(tta >= 0.0 && tta <= 1.0 && ttb >= 0.0 && ttb <= 1.0) {
+	    /* intersection */
+	    *ok = 1;
+	    return;
+	  }
+	}
+      }
+    }
+}
+	 
 
 /*
 
@@ -218,3 +257,72 @@ void xypolyselfint(n, x0, y0, dx, dy,
     }
 }
 	 
+
+/*
+  Just determines whether there is self-intersection
+  (exits quicker & uses less space)
+*/
+
+
+void xypsi(n, x0, y0, dx, dy, xsep, ysep, eps, proper, answer)
+     /* inputs (vectors of coordinates) */
+     int *n;
+     double *x0, *y0, *dx, *dy;
+     /* inputs (distances beyond which intersection is impossible) */
+     double *xsep, *ysep;
+     /* input (tolerance for determinant) */
+     double *eps;  
+     /* input (flag) */
+     int *proper;
+     /* output */
+     int *answer;
+{ 
+  int i, j, m, mm1, mm2, mstop, prop;
+  double determinant, absdet, diffx, diffy, tti, ttj;
+  double Xsep, Ysep;
+
+  m = *n;
+  prop = *proper;
+  Xsep = *xsep;
+  Ysep = *ysep;
+
+  *answer = 0;
+
+  if(m <= 2) 
+    return;
+
+  /* Compare j with j+2, j+3, ...., m-1
+     Don't compare 0 with m-1  */
+  mm1 = m - 1;
+  mm2 = m - 2;
+  for (j=0; j < mm2; j++) 
+    {
+      mstop = (j > 0) ? m : mm1;
+      for(i = j+2; i < mstop; i++) {
+	diffx = x0[j] - x0[i];
+	diffy = y0[j] - y0[i];
+	if(diffx < Xsep && diffx > -Xsep && diffy < Ysep & diffy > -Ysep) {
+	  determinant = dx[j] * dy[i] - dy[j] * dx[i];
+	  absdet = (determinant > 0) ? determinant : -determinant;
+	  if(absdet > *eps) {
+	    diffx = diffx/determinant;
+	    diffy = diffy/determinant;
+	    tti = - dy[j] * diffx + dx[j] * diffy;
+	    ttj = - dy[i] * diffx + dx[i] * diffy;
+	    if(tti >= 0.0 && tti <= 1.0 && ttj >= 0.0 && ttj <= 1.0) {
+              /* intersection occurs */
+	      if(prop == 0 ||
+		 (tti != 0.0 && tti != 1.0) || 
+		 (ttj != 0.0 && ttj != 1.0)) {
+              /* proper intersection */
+		*answer = 1;
+		return;
+	      }
+	    }
+	  }
+	}
+      }
+    }
+}
+
+	 
